@@ -13,7 +13,7 @@ use crate::msbwt_core::*;
 /// This approach is relatively space efficient, but queries may be slower than other approaches.
 pub struct RleBWT {
     bwt: Vec<u8>,
-    total_counts: [u64; VC_LEN],
+    symbol_counts: [u64; VC_LEN],
     start_index: [u64; VC_LEN],
     end_index: [u64; VC_LEN],
     fm_index: [Vec<u64>; VC_LEN],
@@ -29,7 +29,7 @@ impl Default for RleBWT {
         let bin_size: u64 = 0x1 << bin_power;
         Self {
             bwt: vec![],
-            total_counts: [0; VC_LEN],
+            symbol_counts: [0; VC_LEN],
             start_index: [0; VC_LEN],
             end_index: [0; VC_LEN],
             fm_index: Default::default(),
@@ -42,6 +42,20 @@ impl Default for RleBWT {
 }
 
 impl BWT for RleBWT {
+    /// Initializes the BWT from a compressed BWT vector.
+    /// # Arguments
+    /// * `bwt` - the run-length encoded BWT stored in a Vec<u8> 
+    /// # Examples
+    /// ```rust
+    /// use msbwt2::msbwt_core::BWT;
+    /// use msbwt2::rle_bwt::RleBWT;
+    /// use msbwt2::bwt_converter::convert_to_vec;
+    /// //strings "ACGT" and "CCGG"
+    /// let seq = "TG$$CAGCCG";
+    /// let vec = convert_to_vec(seq.as_bytes());
+    /// let mut bwt = RleBWT::new();
+    /// bwt.load_vector(vec);
+    /// ```
     fn load_vector(&mut self, bwt: Vec<u8>) {
         //i am the captain now
         self.bwt = bwt;
@@ -51,6 +65,19 @@ impl BWT for RleBWT {
         self.standard_init();
     }
 
+    /// Initializes the BWT from the numpy file format for compressed BWTs
+    /// # Arguments
+    /// * `filename` - the name of the file to load into memory
+    /// # Examples
+    /// ```rust
+    /// use msbwt2::msbwt_core::BWT;
+    /// use msbwt2::rle_bwt::RleBWT;
+    /// use msbwt2::string_util;
+    /// let mut bwt = RleBWT::new();
+    /// let filename: String = "test_data/two_string.npy".to_string();
+    /// bwt.load_numpy_file(&filename);
+    /// assert_eq!(bwt.count_kmer(&string_util::convert_stoi(&"ACGT")), 1);
+    /// ```
     fn load_numpy_file(&mut self, filename: &str) -> std::io::Result<()> {
         //read the numpy header: http://docs.scipy.org/doc/numpy-1.10.1/neps/npy-format.html
         //get the initial file size
@@ -127,16 +154,51 @@ impl BWT for RleBWT {
         Ok(())
     }
 
+    /// Returns the total number of occurences of a given symbol
+    /// # Arguments
+    /// * `symbol` - the symbol in integer form
+    /// # Examples
+    /// ```rust
+    /// # use msbwt2::msbwt_core::BWT;
+    /// # use msbwt2::rle_bwt::RleBWT;
+    /// # use msbwt2::bwt_converter::convert_to_vec;
+    /// # let seq = "TG$$CAGCCG";
+    /// # let vec = convert_to_vec(seq.as_bytes());
+    /// # let mut bwt = RleBWT::new();
+    /// # bwt.load_vector(vec);
+    /// let string_count = bwt.get_symbol_count(0);
+    /// assert_eq!(string_count, 2);
+    /// ```
     #[inline]
     fn get_symbol_count(&self, symbol: u8) -> u64 {
-        self.total_counts[symbol as usize]
+        self.symbol_counts[symbol as usize]
     }
 
+    /// This will return the total number of symbols contained by the BWT
+    /// # Examples
+    /// ```rust
+    /// # use msbwt2::msbwt_core::BWT;
+    /// # use msbwt2::rle_bwt::RleBWT;
+    /// # use msbwt2::bwt_converter::convert_to_vec;
+    /// # let seq = "TG$$CAGCCG";
+    /// # let vec = convert_to_vec(seq.as_bytes());
+    /// # let mut bwt = RleBWT::new();
+    /// # bwt.load_vector(vec);
+    /// let total_size = bwt.get_total_size();
+    /// assert_eq!(total_size, 10);
+    /// ```
     #[inline]
     fn get_total_size(&self) -> u64 {
         self.total_size
     }
 
+    /// Performs a range constraint on a BWT range. This implicitly represents prepending a character `sym` to a k-mer
+    /// represented by `input_range` to create a new range representing a (k+1)-mer.
+    /// # Arguments
+    /// * `sym` - the symbol to pre-pend in integer form
+    /// * `input_range` - the range to pre-pend to
+    /// # Safety
+    /// This function is unsafe because there are no guarantees that the symbol or bounds will be checked by the implementing structure.
     unsafe fn constrain_range(&self, sym: u8, input_range: &BWTRange) -> BWTRange {
         //first find the low value
         let bin_id: usize = (input_range.l >> self.bin_power) as usize;
@@ -248,7 +310,7 @@ impl RleBWT {
         let bin_size: u64 = 0x1 << bin_power;
         Self {
             bwt: vec![],
-            total_counts: [0; VC_LEN],
+            symbol_counts: [0; VC_LEN],
             start_index: [0; VC_LEN],
             end_index: [0; VC_LEN],
             fm_index: Default::default(),
@@ -294,7 +356,7 @@ impl RleBWT {
         let mut current_count: u64;
 
         //go through each compressed block in the RLE encoded vector to calculate total character counts
-        self.total_counts = [0; VC_LEN];
+        self.symbol_counts = [0; VC_LEN];
         for value in &self.bwt {
             current_char = value & MASK;
             if current_char == prev_char {
@@ -305,7 +367,7 @@ impl RleBWT {
             }
             prev_char = current_char;
             current_count = (value >> LETTER_BITS) as u64 * power_multiple;
-            self.total_counts[current_char as usize] += current_count;
+            self.symbol_counts[current_char as usize] += current_count;
         }
 
         //calculate start/end indices from the total
@@ -314,11 +376,11 @@ impl RleBWT {
         let mut sum_offset: u64 = 0;
         for i in 0..VC_LEN {
             self.start_index[i] = sum_offset;
-            sum_offset += self.total_counts[i];
+            sum_offset += self.symbol_counts[i];
             self.end_index[i] = sum_offset;
         }
         self.total_size = self.end_index[VC_LEN-1];
-        info!("Loaded BWT with symbol counts: {:?}", self.total_counts);
+        info!("Loaded BWT with symbol counts: {:?}", self.symbol_counts);
     }
 
     /// This will create the actual indexing structure. For RLE, it's just a sampled index
